--[[
	We setup the global table for our mod, along with some path variables, and a data table.
	We cache the ModPath directory, so that when our hooks are called, we aren't using the ModPath from a
		different mod.
]]

_G.CrimeNetCleanerSettings = _G.CrimeNetCleanerSettings or {}
CrimeNetCleanerSettings.ModPath = ModPath
CrimeNetCleanerSettings.SaveFilePath = SavePath .. "CrimeNetCleaner.json"
CrimeNetCleanerSettings.JsonOptionsPath = ModPath .. "menu/modoptions.json"
CrimeNetCleanerSettings.data = {}


function CrimeNetCleanerSettings:Save()
	local file = io.open( self.SaveFilePath, "w+" )
	if file then
		file:write( json.encode( self.data ) )
		file:close()
	end
end


function CrimeNetCleanerSettings:Load()
	local file = io.open( self.SaveFilePath, "r" )
	if file then
    self.data = json.decode( file:read("*all") )
		file:close()
	end
end


function CrimeNetCleanerSettings:LoadDefaults()
	-- sets default vals in .data with default_value from menujson  
	local file = io.open(self.JsonOptionsPath, "r")
	if file then
		local file_content = file:read("*all")
		file:close()
        local content = json.decode(file_content)
		local items = content.items

        for _ , item in pairs(items) do
            self.data[item.value] = item.default_value
        end
    end
end
CrimeNetCleanerSettings:LoadDefaults()

-- Taken from Lobby Player Info mod by TdlQ
Hooks:Add("LocalizationManagerPostInit", "LocalizationManagerPostInit_CrimeNetCleanerSettings", function(loc)
    for __, filename in pairs(file.GetFiles(CrimeNetCleanerSettings.ModPath .. "loc/")) do
            local str = filename:match('^(.*).txt$')
            if str and Idstring(str) and Idstring(str):key() == SystemInfo:language():key() then
                    loc:load_localization_file(CrimeNetCleanerSettings.ModPath .. "loc/" .. filename)
                    break
            end
    end
    loc:load_localization_file(CrimeNetCleanerSettings.ModPath .. "loc/english.txt", false)
end)



Hooks:Add( "MenuManagerInitialize", "MenuManagerInitialize_CrimeNetCleanerSettings", function( menu_manager )

    MenuCallbackHandler.cnc_callback_toggle = function(this, item)
        CrimeNetCleanerSettings.data[item:name()] = item:value() == 'on'
        log(json.encode( CrimeNetCleanerSettings.data ))
    end

    MenuCallbackHandler.cnc_callback_save = function(self, item)
		CrimeNetCleanerSettings:Save()
        log("[CrimNET-Cleaner] : settings saved")
	end

	
	CrimeNetCleanerSettings:Load()
	MenuHelper:LoadFromJsonFile( CrimeNetCleanerSettings.JsonOptionsPath, CrimeNetCleanerSettings, CrimeNetCleanerSettings.data )    

end )